@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::App::Command::xtest;
 # ABSTRACT: run xt tests for your dist
 
-our $VERSION = '0.026';
+our $VERSION = '0.027';
 
 use Dist::Zilla::App -command;
 
@@ -63,12 +63,12 @@ sub opt_spec {
         { default => 1 }
       ],
       [ 'automated' => 'enables the AUTOMATED_TESTING env variable', { default => 0 } ],
-      [ 'jobs|j=i'  => 'number of parallel test jobs to run',        { default => 1 } ],
       [
         'all' =>
           'enables the RELEASE_TESTING, AUTOMATED_TESTING and AUTHOR_TESTING env variables',
         { default => 0 }
-      ];
+      ],
+      [ 'jobs|j=i'  => 'number of parallel test jobs to run',        { default => 1 } ];
 }
 
 #pod =head1 OPTIONS
@@ -171,7 +171,7 @@ Dist::Zilla::App::Command::xtest - run xt tests for your dist
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =head1 SYNOPSIS
 
